pub struct JavaPlayer {
pub name: String,
pub id: String,
}Expand description
A single player entry in the status sample list.
Fields
name: StringPlayer’s display name (may differ from their actual username on some servers).
id: StringPlayer’s UUID as a hyphenated string, e.g. "069a79f4-44e9-4726-a5be-fca90e38aaf5".